@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Config;
-$App::ClusterSSH::Config::VERSION = '4.14';
+$App::ClusterSSH::Config::VERSION = '4.15';
 # ABSTRACT: ClusterSSH::Config - Object representing application configuration
 
 =head1 SYNOPSIS
@@ -98,6 +98,8 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
+    command_pre         => q{},
+    command_post        => q{},
     hide_menu           => 0,
     max_host_menu_items => 30,
 
