@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Getopt;
-$App::ClusterSSH::Getopt::VERSION = '4.14';
+$App::ClusterSSH::Getopt::VERSION = '4.15';
 # ABSTRACT: App::ClusterSSH::Getopt - module to process command line args
 
 =head1 SYNOPSIS
@@ -446,6 +446,28 @@ sub _generate_pod {
     }
     print $/, $/;
 
+    output '=head1 ', $self->loc('RELATED');
+    output $self->loc(
+        q{Also see the individual man pages for each of these utilities});
+
+    my %utils = (
+        ctel  => 'telnet',
+        cssh  => 'ssh',
+        crsh  => 'rsh',
+        csftp => 'sftp',
+        ccon  => 'console',
+    );
+
+    output '=over';
+
+    for my $util ( sort grep { !/$Script/ } keys %utils ) {
+        output "=item $util - "
+            . $self->loc( q{Use '[_1]' as the communication method},
+            $utils{$util} );
+    }
+
+    output '=back';
+
     output '=head1 ', $self->loc('DESCRIPTION');
     output $self->loc(
         q{The command opens an administration console and an xterm to all specified hosts.  Any text typed into the administration console is replicated to all windows.  All windows may also be typed into directly.
@@ -680,6 +702,18 @@ would replace the <Alt-n> with the client's name in each window.}
         'Enable or disable alternative algorithm for calculating terminal positioning.',
     );
 
+    output '=item command_pre =';
+    output '=item command_post =';
+    output $self->loc(
+        q{Add extra commands around the communication method.  For example:
+
+command_pre= . $HOME/virtualenvs/default/bin/active ;
+command_post= | ct
+
+would allow for using Python virtual envronments and then piping all shell output through C<chromaterm> for syntax highlighting.  Note: you must use appropriate command separators/terminators to keep the meaning of the command pipline (such as C<;> and C<|> between commands).
+
+These are not put through macro parsing.}
+    );
     output '=item comms = ' . $self->parent->config->{comms};
     output $self->loc(
         'Sets the default communication method (initially taken from the name of the program, but can be overridden here).'
