@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window::Tk;
-$App::ClusterSSH::Window::Tk::VERSION = '4.14';
+$App::ClusterSSH::Window::Tk::VERSION = '4.15';
 # ABSTRACT: Object for creating windows using Tk
 
 use English qw( -no_match_vars );
@@ -314,6 +314,8 @@ sub set_half_inactive() {
     my ($self) = @_;
     $self->debug( 2, "Setting approx half of all hosts to inactive" );
 
+    return if !%servers;
+
     my (@keys) = keys(%servers);
     $#keys /= 2;
     foreach my $svr (@keys) {
@@ -346,7 +348,8 @@ sub add_host_by_name() {
     if ( $menus{host_entry} ) {
         $self->debug( 2, "host=", $menus{host_entry} );
         my @names
-            = $self->resolve_names( split( /\s+/, $menus{host_entry} ) );
+            = $self->parent->resolve_names(
+            split( /\s+/, $menus{host_entry} ) );
         $self->debug( 0, 'Opening to: ', join( ' ', @names ) ) if (@names);
         $self->open_client_windows(@names);
     }
